@@ -1,4 +1,6 @@
 mod mat_vec_mul;
 mod outer;
+mod solve_lin_sys;
 pub use crate::matvec::mat_vec_mul::*;
 pub use crate::matvec::outer::*;
+pub use crate::matvec::solve_lin_sys::*;
